@@ -110,15 +110,16 @@ class SystemNotification:
 class SystemStates(Enum):
     """States that the system can be in."""
 
-    alarm_count = 1
-    away = 2
-    away_count = 3
-    entry_delay = 4
-    error = 5
-    exit_delay = 6
-    home = 7
-    home_count = 8
-    off = 9
+    alarm = 1
+    alarm_count = 2
+    away = 3
+    away_count = 4
+    entry_delay = 5
+    error = 6
+    exit_delay = 7
+    home = 8
+    home_count = 9
+    off = 10
     unknown = 99
 
 
@@ -348,7 +349,7 @@ class System:
 
         _LOGGER.debug("Events response: %s", events_resp)
 
-        return events_resp["events"]
+        return events_resp.get("events", [])
 
     async def get_latest_event(self) -> dict:
         """Get the most recent system event.
@@ -356,7 +357,11 @@ class System:
         :rtype: ``dict``
         """
         events: list = await self.get_events(num_events=1)
-        return events[0]
+
+        try:
+            return events[0]
+        except IndexError:
+            raise SimplipyError("SimpliSafe cloud didn't return any events")
 
     async def get_pins(self, cached: bool = True) -> Dict[str, str]:
         """Return all of the set PINs, including master and duress.
